==> jmax-4.0.0.tar.gz: jmax-4.0.0/java/src/ircam/jmax/toolkit/MouseDragTracker.java <==
//
// jMax
// Copyright (C) 1994, 1995, 1998, 1999 by IRCAM-Centre Georges Pompidou, Paris, France.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// See file LICENSE for further informations on licensing terms.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Based on Max/ISPW by Miller Puckette.
//
// Authors: Maurizio De Cecco, Francois Dechelle, Enzo Maggi, Norbert Schnell.
// 

package ircam.jmax.toolkit;

import java.awt.*;
import java.awt.event.*;


/**
 * a simple interaction module:
 */
public class MouseDragTracker extends InteractionModule {

  /**
   * constructor.
   */
    public MouseDragTracker(DynamicDragListener theListener) 
    {
	super();
	itsListener = theListener;
    }

    public void mousePressed(MouseEvent e) 
    {  
	previousX = e.getX();		
	previousY = e.getY();		
	itsListener.dragStart(previousX, previousY, e);
	InteractionSemaphore.lock();
    }
 
    public void mouseReleased(MouseEvent e) 
    {
	itsListener.dragEnd(e.getX(), e.getY());
	InteractionSemaphore.unlock();
    }

    public void mouseDragged(MouseEvent e) 
    { 
	int deltaY = e.getY()-previousY;
	int deltaX = e.getX()-previousX;

	itsListener.dynamicDrag(deltaX, deltaY, e);
	previousX = e.getX();		
	previousY = e.getY();		
    } 
    
    public void interactionBeginAt(int x, int y)
    {
	//useless for this kind of interaction module
    }

    //------------- fields
    DynamicDragListener itsListener;
    int previousX, previousY;
}

==> jmax-4.1.0.tar.gz: jmax-4.1.0/java/src/ircam/jmax/toolkit/MouseDragTracker.java <==
//
// jMax
// Copyright (C) 1994, 1995, 1998, 1999 by IRCAM-Centre Georges Pompidou, Paris, France.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation; either version 2.1
// of the License, or (at your option) any later version.
// 
// See file COPYING.LIB for further informations on licensing terms.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 

package ircam.jmax.toolkit;

import java.awt.*;
import java.awt.event.*;


/**
 * a simple interaction module:
 */
public class MouseDragTracker extends InteractionModule {

  /**
   * constructor.
   */
    public MouseDragTracker(DynamicDragListener theListener) 
    {
	super();
	itsListener = theListener;
    }

    public void mousePressed(MouseEvent e) 
    {  
	previousX = e.getX();		
	previousY = e.getY();		
	itsListener.dragStart(previousX, previousY, e);
	InteractionSemaphore.lock();
    }
 
    public void mouseReleased(MouseEvent e) 
    {
	itsListener.dragEnd(e.getX(), e.getY(), e);
	InteractionSemaphore.unlock();
    }

    public void mouseDragged(MouseEvent e) 
    { 
	int deltaY = e.getY()-previousY;
	int deltaX = e.getX()-previousX;

	itsListener.dynamicDrag(deltaX, deltaY, e);
	previousX = e.getX();		
	previousY = e.getY();		
    } 
    
    public void interactionBeginAt(int x, int y)
    {
	//useless for this kind of interaction module
    }

    //------------- fields
    DynamicDragListener itsListener;
    int previousX, previousY;
}
